@@ -1,6 +1,6 @@
 /* constants defined for LDAP
  * See http://www.python-ldap.org/ for details.
- * $Id: constants.c,v 1.57 2013/09/11 08:16:27 stroeder Exp $ */
+ * $Id: constants.c,v 1.59 2014/09/12 12:02:21 stroeder Exp $ */
 
 #include "common.h"
 #include "constants.h"
@@ -119,6 +119,9 @@ LDAPinit_constants( PyObject* d )
   add_int(d,SCOPE_BASE);
   add_int(d,SCOPE_ONELEVEL);
   add_int(d,SCOPE_SUBTREE);
+#ifdef LDAP_SCOPE_SUBORDINATE
+  add_int(d,SCOPE_SUBORDINATE);
+#endif
   add_int(d,MOD_ADD);
   add_int(d,MOD_DELETE);
   add_int(d,MOD_REPLACE);
@@ -152,6 +155,7 @@ LDAPinit_constants( PyObject* d )
   add_int(d,OPT_API_FEATURE_INFO);
   add_int(d,OPT_HOST_NAME);
 
+  add_int(d,OPT_DESC);
   add_int(d,OPT_DIAGNOSTIC_MESSAGE);
 
   add_int(d,OPT_ERROR_STRING);
@@ -191,6 +195,9 @@ LDAPinit_constants( PyObject* d )
 #ifdef LDAP_OPT_X_TLS_CIPHER
   add_int(d,OPT_X_TLS_CIPHER);
 #endif
+#ifdef LDAP_OPT_X_TLS_PEERCERT
+  add_int(d,OPT_X_TLS_PEERCERT);
+#endif
 #ifdef LDAP_OPT_X_TLS_CRLCHECK
   /* only available if OpenSSL supports it => might cause backward compability problems */
   add_int(d,OPT_X_TLS_CRLCHECK);
