@@ -1,9 +1,10 @@
 /* See http://www.python-ldap.org/ for details.
- * $Id: functions.c,v 1.23 2009/04/17 12:19:09 stroeder Exp $ */
+ * $Id: functions.c,v 1.27 2009/08/17 05:00:57 leonard Exp $ */
 
 #include "common.h"
 #include "functions.h"
 #include "LDAPObject.h"
+#include "berval.h"
 #include "errors.h"
 #include "options.h"
 
@@ -76,11 +77,9 @@ l_ldap_str2dn( PyObject* unused, PyObject *args )
 	    LDAPAVA *ava = rdn[j];
 	    PyObject *tuple;
 
-	    tuple = Py_BuildValue("(s#s#i)", 
-		ava->la_attr.bv_val,
-		ava->la_attr.bv_len,
-		ava->la_value.bv_val,
-		ava->la_value.bv_len,
+	    tuple = Py_BuildValue("(O&O&i)", 
+		LDAPberval_to_object, &ava->la_attr,
+		LDAPberval_to_object, &ava->la_value,
 		ava->la_flags & ~(LDAP_AVA_FREE_ATTR|LDAP_AVA_FREE_VALUE));
 	    if (!tuple) {
 		Py_DECREF(rdnlist);
@@ -115,10 +114,10 @@ l_ldap_set_option(PyObject* self, PyObject *args)
 
     if (!PyArg_ParseTuple(args, "iO:set_option", &option, &value))
 	return NULL;
-    if (LDAP_set_option(NULL, option, value) == -1)
+    if (!LDAP_set_option(NULL, option, value))
 	return NULL;
     Py_INCREF(Py_None);
-	return Py_None;
+    return Py_None;
 }
 
 /* ldap_get_option (global options) */
