@@ -37,6 +37,7 @@ for entry,test_modlist in addModlist_tests:
 
 print '\nTesting function modifyModlist():'
 modifyModlist_tests = [
+
   (
     {
       'objectClass':['person','pilotPerson'],
@@ -52,6 +53,7 @@ modifyModlist_tests = [
       'enum':['a','b','d'],
       'mail':['michael@stroeder.com'],
     },
+    [],
     [
       (ldap.MOD_DELETE,'objectClass',None),
       (ldap.MOD_ADD,'objectClass',['person','inetOrgPerson']),
@@ -63,6 +65,20 @@ modifyModlist_tests = [
     ]
   ),
 
+  (
+    {
+      'c':['DE'],
+    },
+    {
+      'c':['FR'],
+    },
+    [],
+    [
+      (ldap.MOD_DELETE,'c',None),
+      (ldap.MOD_ADD,'c',['FR']),
+    ]
+  ),
+
   # Now a weird test-case for catching all possibilities
   # of removing an attribute with MOD_DELETE,attr_type,None
   (
@@ -77,17 +93,41 @@ modifyModlist_tests = [
       'cn':[],
       'sn':[None],
     },
+    [],
     [
       (ldap.MOD_DELETE,'c',None),
       (ldap.MOD_DELETE,'objectClass',None),
       (ldap.MOD_DELETE,'sn',None),
     ]
   ),
+
+  (
+    {
+      'objectClass':['person'],
+      'cn':['Michael Str\303\266der','Michael Stroeder'],
+      'sn':['Str\303\266der'],
+      'enum':['a','b','C'],
+    },
+    {
+      'objectClass':['Person'],
+      'cn':['Michael Str\303\266der','Michael Stroeder'],
+      'sn':[],
+      'enum':['a','b','c'],
+    },
+    ['objectClass'],
+    [
+      (ldap.MOD_DELETE,'sn',None),
+      (ldap.MOD_DELETE,'enum',None),
+      (ldap.MOD_ADD,'enum',['a','b','c']),
+    ]
+  ),
+
 ]
-for old_entry,new_entry,test_modlist in modifyModlist_tests:
+for old_entry,new_entry,case_ignore_attr_types,test_modlist in modifyModlist_tests:
   test_modlist.sort()
-  result_modlist = modifyModlist(old_entry,new_entry)
+  result_modlist = modifyModlist(old_entry,new_entry,case_ignore_attr_types=case_ignore_attr_types)
   result_modlist.sort()
+
   if test_modlist!=result_modlist:
     print 'modifyModlist(%s,%s) returns\n%s\ninstead of\n%s.' % (
       repr(old_entry),
