@@ -11,12 +11,17 @@ class MyLDAPUrl(LDAPUrl):
     'trace_level':'trace',
   }
 
+
 ldap_url = MyLDAPUrl(sys.argv[1])
-ldap.trace_level = int(ldap_url.start_tls or '1')
+trace_level = int(ldap_url.trace_level or '0')
+
+print '***trace_level',trace_level
+
+ldap.trace_level = trace_level
 
 l = LDAPObject(
   ldap_url.initializeUrl(),
-  trace_level=int(ldap_url.trace_level or '0'),
+  trace_level=trace_level,
 )
 
 l.protocol_version = 3
@@ -31,3 +36,7 @@ result = l.search_s(
 )
 
 pprint.pprint(result)
+
+print '***DIAGNOSTIC_MESSAGE',repr(l.get_option(ldap.OPT_DIAGNOSTIC_MESSAGE))
+
+l.unbind_s()
